@@ -69,19 +69,19 @@ class EWAHConstants:
             date: 'date',
         },
         DWH_ENGINE_SNOWFLAKE: {
-            QBC_TYPE_MAPPING_DEFAULT: 'text',
-            QBC_TYPE_MAPPING_INCONSISTENT: 'text',
-            str: 'text',
-            int: 'bigint',
-            float: 'numeric',
-            dict: 'jsonb',
-            list: 'jsonb',
-            tuple: 'jsonb',
-            set: 'jsonb',
-            frozenset: 'jsonb',
-            bool: 'boolean',
-            datetime: 'timestamp with time zone',
-            date: 'date',
+            QBC_TYPE_MAPPING_DEFAULT: 'VARIANT',
+            QBC_TYPE_MAPPING_INCONSISTENT: 'VARIANT',
+            str: 'VARCHAR',
+            int: 'NUMBER',
+            float: 'NUMBER',
+            dict: 'OBJECT',
+            list: 'ARRAY',
+            tuple: 'ARRAY',
+            set: 'ARRAY',
+            frozenset: 'ARRAY',
+            bool: 'BOOLEAN',
+            datetime: 'TIMESTAMP_TZ',
+            date: 'DATE',
         },
         DWH_ENGINE_BIGQUERY: {
             QBC_TYPE_MAPPING_DEFAULT: 'STRING',
