@@ -93,9 +93,16 @@ def dag_factory_incremental_loading(
         end_date=None,
         read_right_users=None,
         dwh_ssh_tunnel_conn_id=None,
-        additional_dag_args={},
-        additional_task_args={},
-    ):
+        additional_dag_args=None,
+        additional_task_args=None,
+    **kwargs):
+
+    if kwargs:
+        for key, value in kwargs.items():
+            print('unused config: {0}={1}'.format(key, str(value)))
+            
+    additional_dag_args = additional_dag_args or {}
+    additional_task_args = additional_task_args or {}
 
     if dwh_ssh_tunnel_conn_id and not dwh_engine == EC.DWH_ENGINE_POSTGRES:
         raise Exception('DWH tunneling only implemented for PostgreSQL DWHs!')
@@ -291,6 +298,7 @@ def dag_factory_incremental_loading(
         copy_schema=True,
         target_schema_name=target_schema_name,
         target_schema_suffix=target_schema_suffix,
+        target_database_name=target_database_name,
         dwh_conn_id=dwh_conn_id,
         read_right_users=read_right_users,
         ssh_tunnel_conn_id=dwh_ssh_tunnel_conn_id,
@@ -304,6 +312,7 @@ def dag_factory_incremental_loading(
         copy_schema=True,
         target_schema_name=target_schema_name,
         target_schema_suffix=target_schema_suffix,
+        target_database_name=target_database_name,
         dwh_conn_id=dwh_conn_id,
         read_right_users=read_right_users,
         ssh_tunnel_conn_id=dwh_ssh_tunnel_conn_id,
@@ -352,10 +361,6 @@ def dag_factory_incremental_loading(
             'target_schema_suffix': target_schema_suffix,
             'target_database_name': target_database_name,
             'target_ssh_tunnel_conn_id': dwh_ssh_tunnel_conn_id,
-            # 'drop_and_replace': False,
-            # columns_definition
-            # update_on_columns
-            # primary_key_column_name
         }
 
         arg_dict_backfill = deepcopy(arg_dict)
