@@ -4,6 +4,7 @@ from airflow.utils.decorators import apply_defaults
 
 from ewah.dwhooks import get_dwhook
 from ewah.constants import EWAHConstants as EC
+from ewah.ewah_utils.ssh_tunnel import start_ssh_tunnel
 
 import hashlib
 
@@ -88,9 +89,24 @@ class EWAHBaseOperator(BaseOperator):
         # columns_definition was supplied (e.g. for select * with sql)
         index_columns=[], # list of columns to create an index on. can be
         # an expression, must be quoted in list of quoting is required.
+        source_ssh_tunnel_conn_id=None, # create SSH tunnel if set; uses host
+        # and port from source_conn_id as remote host and port
+        target_ssh_tunnel_conn_id=None, # see source_ssh_tunnel_conn_id
+        hash_columns=None, # str or list of str - columns to hash pre-upload
+        hashlib_func_name='sha256', # specify hashlib hashing function
     *args, **kwargs):
         super().__init__(*args, **kwargs)
 
+        if hash_columns and not clean_data_before_upload:
+            _msg = 'column hashing is only possible with data cleaning!'
+            raise Exception(_msg)
+        elif isinstance(hash_columns, str):
+            hash_columns = [hash_columns]
+        if hashlib_func_name:
+            _msg = 'Invalid hashing function: hashlib.{0}()'
+            _msg = _msg.format(hashlib_func_name)
+            assert hasattr(hashlib, hashlib_func_name), _msg
+
         if columns_definition and exclude_columns:
             raise Exception('Must not supply both columns_definition and ' \
                 + 'exclude_columns!')
@@ -170,6 +186,10 @@ class EWAHBaseOperator(BaseOperator):
         self.add_metadata = add_metadata
         self.exclude_columns = exclude_columns
         self.index_columns = index_columns
+        self.source_ssh_tunnel_conn_id = source_ssh_tunnel_conn_id
+        self.target_ssh_tunnel_conn_id = target_ssh_tunnel_conn_id
+        self.hash_columns = hash_columns
+        self.hashlib_func_name = hashlib_func_name
 
         self.hook = get_dwhook(self.dwh_engine)
 
@@ -181,42 +201,88 @@ class EWAHBaseOperator(BaseOperator):
             the child operators shall have an ewah_execute() function which is
             called by this general execute() method.
         """
+
+        def close_ssh_tunnels():
+            # close SSH tunnels if they exist
+            if hasattr(self, 'source_ssh_tunnel_forwarder'):
+                self.source_ssh_tunnel_forwarder.stop()
+                del self.source_ssh_tunnel_forwarder
+            if hasattr(self, 'target_ssh_tunnel_forwarder'):
+                self.target_ssh_tunnel_forwarder.stop()
+                del self.target_ssh_tunnel_forwarder
+
         # the upload hook is used in the self.upload_data() function
         # which is called by the child's ewah_execute function whenever there is
-        # data to upload.
-        self.upload_hook = self.hook(self.dwh_conn_id)
-        # execute operator
-        result = self.ewah_execute(context)
-        # if PostgreSQL and arg given: create indices
-        for column in self.index_columns:
-            # Use hashlib to create a unique 63 character string as index
-            # name to avoid breaching index name length limits and accidental
-            # duplicates / missing indices due to name truncation leading to
-            # identical index names.
-            self.hook.execute(self._INDEX_QUERY.format(
-                '__ewah_' + hashlib.blake2b(
-                    (self.target_schema_name
-                        + self.target_schema_suffix
-                        + '.'
-                        + self.target_table_name
-                        + '.'
-                        + column
-                    ).encode(),
-                    digest_size=28,
-                ).hexdigest(),
-                self.target_schema_name + self.target_schema_suffix,
-                self.target_table_name,
-                column,
-            ))
-        # commit only at the end, so that no data may be committed before an
-        # error occurs.
-        self.log.info('Now committing changes!')
-        self.upload_hook.commit()
-        self.upload_hook.close()
+        # data to upload. If applicable: start SSH tunnel first!
+        if self.target_ssh_tunnel_conn_id:
+            self.log.info('Opening SSH tunnel to target...')
+            self.target_ssh_tunnel_forwarder, self.dwh_conn = start_ssh_tunnel(
+                ssh_conn_id=self.target_ssh_tunnel_conn_id,
+                remote_conn_id=self.dwh_conn_id,
+            )
+        else:
+            self.dwh_conn = BaseHook.get_connection(self.dwh_conn_id)
+        self.upload_hook = self.hook(self.dwh_conn)
+
+        # open SSH tunnel for the data source connection, if applicable
+        if self.source_ssh_tunnel_conn_id:
+            #if self.target_ssh_tunnel_conn_id:
+            #    local_port = self.dwh_conn.port + 1
+            #else:
+            #    local_port = 0 # random assignment
+            self.log.info('Opening SSH tunnel to source...')
+            self.source_ssh_tunnel_forwarder, self.source_conn=start_ssh_tunnel(
+                ssh_conn_id=self.source_ssh_tunnel_conn_id,
+                remote_conn_id=self.source_conn_id,
+            )
+        elif self.source_conn_id:
+            # resolve conn id here & delete the object to avoid usage elsewhere
+            self.source_conn = BaseHook.get_connection(self.source_conn_id)
+        del self.source_conn_id
+
+        try:
+            # execute operator
+            result = self.ewah_execute(context)
+
+            # if PostgreSQL and arg given: create indices
+            for column in self.index_columns:
+                # Use hashlib to create a unique 63 character string as index
+                # name to avoid breaching index name length limits & accidental
+                # duplicates / missing indices due to name truncation leading to
+                # identical index names.
+                self.hook.execute(self._INDEX_QUERY.format(
+                    '__ewah_' + hashlib.blake2b(
+                        (self.target_schema_name
+                            + self.target_schema_suffix
+                            + '.'
+                            + self.target_table_name
+                            + '.'
+                            + column
+                        ).encode(),
+                        digest_size=28,
+                    ).hexdigest(),
+                    self.target_schema_name + self.target_schema_suffix,
+                    self.target_table_name,
+                    column,
+                ))
+
+            # commit only at the end, so that no data may be committed before an
+            # error occurs.
+            self.log.info('Now committing changes!')
+            self.upload_hook.commit()
+            self.upload_hook.close()
+        except:
+            # close SSH tunnels on failure before raising the error
+            close_ssh_tunnels()
+            raise
+
+        # everything worked, now close SSH tunnels
+        close_ssh_tunnels()
+
         return result
 
     def test_if_target_table_exists(self):
-        hook = self.hook(self.dwh_conn_id)
+        hook = self.hook(self.dwh_conn)
         if self.dwh_engine == EC.DWH_ENGINE_POSTGRES:
             result = hook.test_if_table_exists(
                 table_name=self.target_table_name,
@@ -253,6 +319,13 @@ class EWAHBaseOperator(BaseOperator):
             for field in datum.keys():
                 if field in self.exclude_columns:
                     datum[field] = None
+                elif field in (self.hash_columns or []) \
+                    and not result.get(field):
+                     # Type is appropriate string type & QBC_FIELD_HASH is true
+                     result.update({field:{
+                        EC.QBC_FIELD_TYPE: get_field_type('str'),
+                        EC.QBC_FIELD_HASH: True,
+                     }})
                 elif not (result.get(field, {}).get(EC.QBC_FIELD_TYPE) \
                     == inconsistent_data_type) and (not datum[field] is None):
                     if result.get(field):
@@ -312,8 +385,9 @@ class EWAHBaseOperator(BaseOperator):
 
         if (not self.drop_and_replace) or (self.upload_call_count > 1):
             self.log.info('Checking for, and applying schema changes.')
+            _new_schema_name = self.target_schema_name+self.target_schema_suffix
             new_cols, del_cols = hook.detect_and_apply_schema_changes(
-                new_schema_name=self.target_schema_name+self.target_schema_suffix,
+                new_schema_name=_new_schema_name,
                 new_table_name=self.target_table_name,
                 new_columns_dictionary=columns_definition,
                 # When introducing a feature utilizing this, remember to
@@ -338,11 +412,13 @@ class EWAHBaseOperator(BaseOperator):
             drop_and_replace=self.drop_and_replace and \
                 (self.upload_call_count == 1), # In case of chunking of uploads
             update_on_columns=self.update_on_columns,
-            commit=False,
+            commit=False, # See note below for reason
             logging_function=self.log.info,
             clean_data_before_upload=self.clean_data_before_upload,
+            hash_columns=self.hash_columns,
+            hashlib_func_name=self.hashlib_func_name,
         )
-        """ Note on commiting changes:
+        """ Note on committing changes:
             The hook used for data uploading is created at the beginning of the
             execute function and automatically committed and closed at the end.
             DO NOT commit in this function, as multiple uploads may be required,
