@@ -1,10 +1,10 @@
 from ewah.operators.sql_base_operator import EWAHSQLBaseOperator
 from ewah.constants import EWAHConstants as EC
 
-from mysql.connector import connect
-
 from airflow.hooks.base_hook import BaseHook
 
+import pymysql
+
 class EWAHMySQLOperator(EWAHSQLBaseOperator):
 
     _SQL_BASE = \
@@ -24,20 +24,24 @@ class EWAHMySQLOperator(EWAHSQLBaseOperator):
         super().__init__(*args, **kwargs)
 
     def _get_data_from_sql(self, sql, params=None, return_dict=True):
-        connection = BaseHook.get_connection(self.source_conn_id)
-        database_conn = connect(**{
-            'host': connection.host,
-            'user': connection.login,
-            'passwd': connection.password,
-            'port': connection.port,
-            'database': connection.schema,
+        if return_dict:
+            cursor_class = pymysql.cursors.DictCursor
+        else:
+            cursor_class = pymysql.cursors.Cursor
+        database_conn = pymysql.connect(**{
+            'host': self.source_conn.host,
+            'user': self.source_conn.login,
+            'passwd': self.source_conn.password,
+            'port': self.source_conn.port,
+            'database': self.source_conn.schema,
+            'cursorclass': cursor_class,
         })
-        cursor = database_conn.cursor(dictionary=return_dict)
+        cursor = database_conn.cursor()
         self.log.info('Executing:\n{0}\n\nWith params:\n{1}'.format(
             sql,
             str(params),
         ))
-        cursor.execute(sql, params=params)
+        cursor.execute(sql, args=params)
         data = cursor.fetchall()
         cursor.close()
         database_conn.close()
